@@ -1,6 +1,7 @@
 # system configuration generated and used by the sysconfig module
 build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
+ 'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
@@ -10,8 +11,8 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECPPFLAGS': '-IObjects -IInclude -IPython',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
- 'BINLIBDEST': '/usr/lib/python3.8',
- 'BLDLIBRARY': 'libpython3.8.dll.a',
+ 'BINLIBDEST': '/usr/lib/python3.9',
+ 'BLDLIBRARY': 'libpython3.9.dll.a',
  'BLDSHARED': 'gcc -shared -Wl,--enable-auto-image-base',
  'BUILDEXE': '.exe',
  'BUILDPYTHON': 'python.exe',
@@ -22,14 +23,14 @@ build_time_vars = {'ABIFLAGS': '',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
            '-ggdb -O2 -pipe -Wall -Werror=format-security '
            '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-           '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
-           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1 '
+           '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ '
+           '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
+           '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1 '
            '-ggdb -O2 -pipe -Wall -Werror=format-security '
            '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
-           '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
-           '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1',
+           '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ '
+           '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
+           '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1',
  'CFLAGSFORSHARED': '',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -38,44 +39,46 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS': '-ggdb -O2 -pipe -Wall -Werror=format-security '
                      '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                      '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                     '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
-                     '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1',
+                     '-I/usr/include/uuid/ '
+                     '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
+                     '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Wstrict-prototypes '
-                            '-Werror=implicit-function-declaration',
+                            '-Werror=implicit-function-declaration '
+                            '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
  'CONFIGURE_LDFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '',
- 'CONFIG_ARGS': "'--srcdir=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16' "
+ 'CONFIG_ARGS': "'--srcdir=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9' "
                 "'--prefix=/usr' '--exec-prefix=/usr' '--localstatedir=/var' "
-                "'--sysconfdir=/etc' '--docdir=/usr/share/doc/python38' "
-                "'--htmldir=/usr/share/doc/python38/html' '-C' "
+                "'--sysconfdir=/etc' '--docdir=/usr/share/doc/python39' "
+                "'--htmldir=/usr/share/doc/python39/html' '-C' "
                 "'--enable-shared' '--enable-ipv6' '--with-libc=' "
                 "'--with-libm=' '--with-system-expat' '--with-system-ffi' "
-                "'--without-ensurepip' '--enable-loadable-sqlite-extensions' "
+                "'--without-ensurepip' "
                 "'ac_cv_func_bind_textdomain_codeset=yes' 'CC=gcc' "
                 "'CFLAGS=-ggdb -O2 -pipe -Wall -Werror=format-security "
                 '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                 '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
-                "-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1' "
+                '-I/usr/include/uuid/ '
+                '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
+                "-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1' "
                 "'LDFLAGS=' 'LIBS=' 'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
- 'CONFINCLUDEPY': '/usr/include/python3.8',
+ 'CONFINCLUDEPY': '/usr/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/pub/devel/python/python38/python38-3.8.16-1.x86_64/build/coverage.info',
- 'COVERAGE_REPORT': '/pub/devel/python/python38/python38-3.8.16-1.x86_64/build/lcov-report',
+ 'COVERAGE_INFO': '/pub/devel/python/python39/python39-3.9.9-1.x86_64/build/coverage.info',
+ 'COVERAGE_REPORT': '/pub/devel/python/python39/python39-3.9.9-1.x86_64/build/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include',
+             '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include',
  'CXX': 'g++',
- 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.8 /usr/lib/python3.8/lib-dynload',
- 'DESTLIB': '/usr/lib/python3.8',
+ 'DESTDIRS': '/usr /usr/lib /usr/lib/python3.9 /usr/lib/python3.9/lib-dynload',
+ 'DESTLIB': '/usr/lib/python3.9',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/lib/python3.8/lib-dynload',
+ 'DESTSHARED': '/usr/lib/python3.9/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -84,7 +87,7 @@ build_time_vars = {'ABIFLAGS': '',
  'DISTFILES': 'README.rst ChangeLog configure configure.ac acconfig.h '
               'pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
- 'DLLLIBRARY': 'libpython3.8.dll',
+ 'DLLLIBRARY': 'libpython3.9.dll',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
@@ -97,14 +100,15 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '.exe',
  'EXEMODE': 755,
+ 'EXPORTSFROM': '',
+ 'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.cpython-38-x86_64-cygwin.dll',
+ 'EXT_SUFFIX': '.cpython-39-x86_64-cygwin.dll',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
- 'GETTIMEOFDAY_NO_TZ': 0,
  'GITBRANCH': '',
  'GITTAG': '',
  'GITVERSION': '',
@@ -260,7 +264,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GETSID': 1,
  'HAVE_GETSPENT': 0,
  'HAVE_GETSPNAM': 0,
- 'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
@@ -292,18 +295,22 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBUTIL_H': 0,
+ 'HAVE_LIBUUID': 1,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
  'HAVE_LINUX_CAN_BCM_H': 0,
  'HAVE_LINUX_CAN_H': 0,
+ 'HAVE_LINUX_CAN_J1939_H': 0,
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 0,
  'HAVE_LINUX_CAN_RAW_H': 0,
+ 'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 0,
  'HAVE_LINUX_MEMFD_H': 0,
  'HAVE_LINUX_NETLINK_H': 0,
  'HAVE_LINUX_QRTR_H': 0,
  'HAVE_LINUX_RANDOM_H': 0,
  'HAVE_LINUX_TIPC_H': 0,
  'HAVE_LINUX_VM_SOCKETS_H': 0,
+ 'HAVE_LINUX_WAIT_H': 0,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -314,7 +321,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
  'HAVE_MEMFD_CREATE': 0,
- 'HAVE_MEMORY_H': 0,
+ 'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 1,
  'HAVE_MKDIRAT': 1,
  'HAVE_MKFIFO': 1,
@@ -329,6 +336,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_NETPACKET_PACKET_H': 0,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
+ 'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_PATHCONF': 1,
@@ -355,7 +363,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 1,
- 'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 0,
  'HAVE_PWRITEV2': 0,
@@ -380,6 +387,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SCHED_SETAFFINITY': 1,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
+ 'HAVE_SEM_CLOCKWAIT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -507,7 +515,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
- 'HAVE_UNSETENV': 1,
  'HAVE_USABLE_WCHAR_T': 1,
  'HAVE_UTIL_H': 0,
  'HAVE_UTIMENSAT': 1,
@@ -516,7 +523,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UUID_CREATE': 0,
  'HAVE_UUID_ENC_BE': 0,
  'HAVE_UUID_GENERATE_TIME_SAFE': 1,
- 'HAVE_UUID_H': 0,
+ 'HAVE_UUID_H': 1,
  'HAVE_UUID_UUID_H': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
@@ -533,36 +540,36 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'x86_64-pc-cygwin',
- 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.8 '
-                   '/usr/include/python3.8',
+ 'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.9 '
+                   '/usr/include/python3.9',
  'INCLUDEDIR': '/usr/include',
- 'INCLUDEPY': '/usr/include/python3.8',
+ 'INCLUDEPY': '/usr/include/python3.9',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 755',
- 'INSTSONAME': 'libpython3.8.dll.a',
+ 'INSTSONAME': 'libpython3.9.dll.a',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared -Wl,--enable-auto-image-base',
  'LDFLAGS': '',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.8.dll.a',
+ 'LDLIBRARY': 'libpython3.9.dll.a',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -shared -Wl,--enable-auto-image-base',
- 'LDVERSION': '3.8',
+ 'LDVERSION': '3.9',
  'LIBC': '',
- 'LIBDEST': '/usr/lib/python3.8',
+ 'LIBDEST': '/usr/lib/python3.9',
  'LIBDIR': '/usr/lib',
  'LIBFFI_INCLUDEDIR': '',
  'LIBM': '',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/lib/pkgconfig',
- 'LIBPL': '/usr/lib/python3.8/config-3.8-x86_64-cygwin',
- 'LIBPYTHON': '-lpython3.8',
- 'LIBRARY': 'libpython3.8.a',
+ 'LIBPL': '/usr/lib/python3.9/config-3.9-x86_64-cygwin',
+ 'LIBPYTHON': '-lpython3.9',
+ 'LIBRARY': 'libpython3.9.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lcrypt -lintl -ldl',
@@ -578,18 +585,18 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'cygwin',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/lib/python3.8',
+ 'MACHDESTLIB': '/usr/lib/python3.9',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
- 'MAJOR_IN_SYSMACROS': 1,
- 'MAKESETUP': '/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Modules/makesetup',
+ 'MAJOR_IN_SYSMACROS': 0,
+ 'MAKESETUP': '/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
-                   '_tracemalloc  _symtable  parser  xxsubtype',
+                   '_tracemalloc  _peg_parser  _symtable  parser  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
@@ -602,7 +609,7 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
             'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
             'Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o Modules/hashtable.o  '
+            'Modules/_tracemalloc.o  Modules/_peg_parser.o  '
             'Modules/symtablemodule.o  Modules/parsermodule.o  '
             'Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
@@ -623,9 +630,13 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/parsetok.o '
+                'Parser/tokenizer.o',
+ 'PEGEN_HEADERS': '\\',
+ 'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
+ 'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test --pgo',
@@ -641,68 +652,74 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python.exe -E',
- 'PYTHON_FOR_REGEN': 'python3.8',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g '
                              '-fwrapv -O3 -Wall -ggdb -O2 -pipe -Wall '
                              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                              '-fstack-protector-strong '
                              '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
-                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1 '
+                             '-I/usr/include/uuid/ '
+                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
+                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1 '
                              '-ggdb -O2 -pipe -Wall -Werror=format-security '
                              '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                              '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
-                             '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1 '
+                             '-I/usr/include/uuid/ '
+                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
+                             '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1 '
                              '-std=c99 -Wextra -Wno-unused-result '
                              '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
-                             '-Wstrict-prototypes '
-                             '-Werror=implicit-function-declaration  '
-                             '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include/internal '
+                             '-Werror=implicit-function-declaration '
+                             '-fvisibility=hidden  '
+                             '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
-                             '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include '
+                             '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 -Wall '
               '-ggdb -O2 -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
               '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
-              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1 '
+              '-I/usr/include/uuid/ '
+              '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
+              '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1 '
               '-ggdb -O2 -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
               '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
-              '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1',
+              '-I/usr/include/uuid/ '
+              '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
+              '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Wstrict-prototypes '
-                     '-Werror=implicit-function-declaration  '
-                     '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include/internal',
+                     '-Werror=implicit-function-declaration '
+                     '-fvisibility=hidden  '
+                     '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -g -fwrapv -O3 '
                    '-Wall -ggdb -O2 -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                    '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
-                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1 '
+                   '-I/usr/include/uuid/ '
+                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
+                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1 '
                    '-ggdb -O2 -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                    '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
-                   '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1 '
+                   '-I/usr/include/uuid/ '
+                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
+                   '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1 '
                    '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration  '
-                   '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include/internal '
+                   '-Wno-missing-field-initializers '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
+                   '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include '
+                   '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include',
+                '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
  'PY_LDFLAGS_NODIST': '',
@@ -712,21 +729,22 @@ build_time_vars = {'ABIFLAGS': '',
                         '-O3 -Wall -ggdb -O2 -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                        '-DOPENSSL_NO_SSL3=1 '
-                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
-                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1 '
+                        '-DOPENSSL_NO_SSL3=1 -I/usr/include/uuid/ '
+                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
+                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1 '
                         '-ggdb -O2 -pipe -Wall -Werror=format-security '
                         '-Wp,-D_FORTIFY_SOURCE=2 -fstack-protector-strong '
                         '--param=ssp-buffer-size=4 -DOPENSSL_NO_SSL3=1 '
-                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/build=/usr/src/debug/python38-3.8.16-1 '
-                        '-fdebug-prefix-map=/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16=/usr/src/debug/python38-3.8.16-1 '
+                        '-I/usr/include/uuid/ '
+                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/build=/usr/src/debug/python39-3.9.9-1 '
+                        '-fdebug-prefix-map=/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9=/usr/src/debug/python39-3.9.9-1 '
                         '-std=c99 -Wextra -Wno-unused-result '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
-                        '-Wstrict-prototypes '
-                        '-Werror=implicit-function-declaration  '
-                        '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include/internal '
+                        '-Werror=implicit-function-declaration '
+                        '-fvisibility=hidden  '
+                        '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
-                        '-I/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Include',
+                        '-I/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Include',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -738,7 +756,6 @@ build_time_vars = {'ABIFLAGS': '',
  'RUNSHARED': '',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
- 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
  'SHLIBS': '-lcrypt -lintl -ldl',
  'SHLIB_SUFFIX': '.dll',
@@ -763,9 +780,9 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 8,
  'SIZEOF_WCHAR_T': 2,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-38-x86_64-cygwin',
- 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
- 'SRC_GDB_HOOKS': '/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Tools/gdb/libpython.py',
+ 'SOABI': 'cpython-39-x86_64-cygwin',
+ 'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
+ 'SRC_GDB_HOOKS': '/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -780,18 +797,19 @@ build_time_vars = {'ABIFLAGS': '',
  'TESTPYTHON': './python.exe',
  'TESTPYTHONOPTS': '',
  'TESTRUNNER': './python.exe '
-               '/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Tools/scripts/run_tests.py',
+               '/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
+ 'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': 'python3.8 '
-                '/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16/Tools/scripts/update_file.py',
+ 'UPDATE_FILE': 'python3 '
+                '/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
- 'VERSION': '3.8',
- 'VPATH': '/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16',
+ 'VERSION': '3.9',
+ 'VPATH': '/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9',
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -803,9 +821,9 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/pub/devel/python/python38/python38-3.8.16-1.x86_64/build',
- 'abs_srcdir': '/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16',
+ 'abs_builddir': '/pub/devel/python/python39/python39-3.9.9-1.x86_64/build',
+ 'abs_srcdir': '/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/pub/devel/python/python38/python38-3.8.16-1.x86_64/src/Python-3.8.16'}
+ 'srcdir': '/pub/devel/python/python39/python39-3.9.9-1.x86_64/src/Python-3.9.9'}
